@@ -144,9 +144,9 @@ class ElementsConnectorTest(cloud_elements.ElementsConnector):
         self.element_token = element_token
 
     @ElementsTimer.time_me
-    def invoke(self, http_method, hub_name, element_token, api, version='1', params=None, payload=None, files=None):
+    def invoke(self, http_method, hub_name, api, version='1', params=None, payload=None, files=None, headers=None):
         return cloud_elements.ElementsConnector.invoke(self, httpMethod=http_method, providerName=hub_name,
-                                                       elementToken=element_token, apiMethodName=api,
+                                                       headers=headers, apiMethodName=api,
                                                        providerVersion=version, params=params,
                                                        payload=payload,
                                                        files=files)
